.. pysndfile documentation master file, created by
   sphinx-quickstart on Sun Jun 10 01:17:10 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

 Welcome to pysndfile's documentation!
========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:
             
   LONG_DESCR
   modules 
   GeneralInfo
   Changes
   
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

